import logging
import subprocess

import treefiles as tf


def serve():
    # to stop: `netstat -tulpn | grep LISTEN |grep 3000` to get the pid
    # and `kill -9 <pid>`
    subprocess.call(["serve", "-s", tf.f(__file__) / "build"])


log = logging.getLogger(__name__)

if __name__ == "__main__":
    logging.basicConfig(level=logging.DEBUG)
    log = tf.get_logger()

    serve()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="dash_cm",
    version="0.1.010",
    # author="",
    # author_email="",
    # url="",
    description="Description",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
)
